@@ -40,7 +40,9 @@ typedef enum
   WNCK_WINDOW_STATE_SHADED                 = 1 << 3,
   WNCK_WINDOW_STATE_SKIP_PAGER             = 1 << 4,
   WNCK_WINDOW_STATE_SKIP_TASKLIST          = 1 << 5,
-  WNCK_WINDOW_STATE_STICKY                 = 1 << 6
+  WNCK_WINDOW_STATE_STICKY                 = 1 << 6,
+  WNCK_WINDOW_STATE_HIDDEN                 = 1 << 7,
+  WNCK_WINDOW_STATE_FULLSCREEN             = 1 << 8
 } WnckWindowState;
 
 typedef enum
@@ -63,6 +65,19 @@ typedef enum
   WNCK_WINDOW_ACTION_UNMAXIMIZE              = 1 << 15
 } WnckWindowActions;
 
+typedef enum
+{
+  WNCK_WINDOW_NORMAL,       /* document/app window */
+  WNCK_WINDOW_DESKTOP,      /* desktop background */
+  WNCK_WINDOW_DOCK,         /* panel */
+  WNCK_WINDOW_DIALOG,       /* dialog */
+  WNCK_WINDOW_MODAL_DIALOG, /* modal dialog */
+  WNCK_WINDOW_TOOLBAR,      /* tearoff toolbar */
+  WNCK_WINDOW_MENU,         /* tearoff menu */
+  WNCK_WINDOW_UTILITY,      /* palette/toolbox window */
+  WNCK_WINDOW_SPLASHSCREEN  /* splash screen */
+} WnckWindowType;
+
 #define WNCK_TYPE_WINDOW              (wnck_window_get_type ())
 #define WNCK_WINDOW(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), WNCK_TYPE_WINDOW, WnckWindow))
 #define WNCK_WINDOW_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), WNCK_TYPE_WINDOW, WnckWindowClass))
@@ -120,11 +135,14 @@ const char* wnck_window_get_icon_name (WnckWindow *window);
 
 WnckApplication* wnck_window_get_application  (WnckWindow *window);
 gulong           wnck_window_get_group_leader (WnckWindow *window);
+gulong           wnck_window_get_xid          (WnckWindow *window);
 
 const char* wnck_window_get_session_id        (WnckWindow *window);
 const char* wnck_window_get_session_id_utf8   (WnckWindow *window);
 int         wnck_window_get_pid               (WnckWindow *window);
 
+WnckWindowType wnck_window_get_window_type    (WnckWindow *window);
+
 gboolean wnck_window_is_minimized              (WnckWindow *window);
 gboolean wnck_window_is_maximized_horizontally (WnckWindow *window);
 gboolean wnck_window_is_maximized_vertically   (WnckWindow *window);
@@ -134,6 +152,11 @@ gboolean wnck_window_is_skip_pager             (WnckWindow *window);
 gboolean wnck_window_is_skip_tasklist          (WnckWindow *window);
 gboolean wnck_window_is_sticky                 (WnckWindow *window);
 
+void wnck_window_set_skip_pager    (WnckWindow *window,
+                                    gboolean skip);
+void wnck_window_set_skip_tasklist (WnckWindow *window,
+                                    gboolean skip);
+
 void wnck_window_close                   (WnckWindow *window);
 void wnck_window_minimize                (WnckWindow *window);
 void wnck_window_unminimize              (WnckWindow *window);
@@ -147,6 +170,8 @@ void wnck_window_shade                   (WnckWindow *window);
 void wnck_window_unshade                 (WnckWindow *window);
 void wnck_window_stick                   (WnckWindow *window);
 void wnck_window_unstick                 (WnckWindow *window);
+void wnck_window_keyboard_move           (WnckWindow *window);
+void wnck_window_keyboard_size           (WnckWindow *window);
 
 WnckWorkspace* wnck_window_get_workspace     (WnckWindow    *window);
 void           wnck_window_move_to_workspace (WnckWindow    *window,
@@ -159,19 +184,19 @@ void     wnck_window_unpin     (WnckWindow *window);
 
 void     wnck_window_activate  (WnckWindow *window);
 gboolean wnck_window_is_active (WnckWindow *window);
+void     wnck_window_activate_transient (WnckWindow *window);
 
 
 GdkPixbuf* wnck_window_get_icon      (WnckWindow *window);
 GdkPixbuf* wnck_window_get_mini_icon (WnckWindow *window);
 
-void wnck_window_set_create_fallback_icon (WnckWindow *window,
-                                           gboolean    setting);
-void wnck_window_set_icon_size            (WnckWindow *window,
-                                           int         width,
-                                           int         height);
-void wnck_window_set_mini_icon_size       (WnckWindow *window,
-                                           int         width,
-                                           int         height);
+gboolean wnck_window_get_icon_is_fallback (WnckWindow *window);
+
+void wnck_window_set_icon_geometry        (WnckWindow *window,
+					   int         x,
+					   int         y,
+					   int         width,
+					   int         height);
 
 WnckWindowActions wnck_window_get_actions (WnckWindow *window);
 WnckWindowState   wnck_window_get_state   (WnckWindow *window);
@@ -186,6 +211,8 @@ gboolean wnck_window_is_visible_on_workspace (WnckWindow    *window,
                                               WnckWorkspace *workspace);
 gboolean wnck_window_is_on_workspace         (WnckWindow    *window,
                                               WnckWorkspace *workspace);
+gboolean wnck_window_is_in_viewport          (WnckWindow    *window,
+                                              WnckWorkspace *workspace);
 
 G_END_DECLS
 
