@@ -557,7 +557,7 @@ _wnck_get_utf8_list (Window   xwindow,
    * property is nul-separated
    */
   i = 0;
-  n_strings = 1;
+  n_strings = 0;
   while (i < nitems)
     {
       if (val[i] == '\0')
@@ -565,6 +565,9 @@ _wnck_get_utf8_list (Window   xwindow,
       ++i;
     }
 
+  if (val[nitems - 1] != '\0')
+    ++n_strings;
+
   /* we're guaranteed that val has a nul on the end
    * by XGetWindowProperty
    */
@@ -1014,6 +1017,31 @@ _wnck_activate_workspace (Screen *screen,
 	      &xev);
 }
 
+void
+_wnck_change_viewport (Screen *screen,
+		       int     x,
+		       int     y)
+{
+  XEvent xev;
+  
+  xev.xclient.type = ClientMessage;
+  xev.xclient.serial = 0;
+  xev.xclient.send_event = True;
+  xev.xclient.display = gdk_display;
+  xev.xclient.window = RootWindowOfScreen (screen);
+  xev.xclient.message_type = _wnck_atom_get ("_NET_DESKTOP_VIEWPORT");
+  xev.xclient.format = 32;
+  xev.xclient.data.l[0] = x;
+  xev.xclient.data.l[1] = y;
+  xev.xclient.data.l[2] = 0;
+
+  XSendEvent (gdk_display,
+	      RootWindowOfScreen (screen),
+              False,
+	      SubstructureRedirectMask | SubstructureNotifyMask,
+	      &xev);
+}
+
 void
 _wnck_toggle_showing_desktop (Screen  *screen,
                               gboolean show)
@@ -1129,6 +1157,18 @@ latin1_to_utf8 (const char *latin1)
 
 char*
 _wnck_get_res_class_utf8 (Window xwindow)
+{
+  char *res_class;
+
+  _wnck_get_wmclass (xwindow, &res_class, NULL);
+
+  return res_class;
+}
+
+void
+_wnck_get_wmclass (Window xwindow,
+                   char **res_class,
+                   char **res_name)
 {
   XClassHint ch;
   char *retval;
@@ -1144,19 +1184,28 @@ _wnck_get_res_class_utf8 (Window xwindow)
   _wnck_error_trap_pop ();
   
   retval = NULL;
+
+  if (res_class)
+    *res_class = NULL;
+
+  if (res_name)
+    *res_name = NULL;
   
   if (ch.res_name)
     {
+      if (res_name)
+        *res_name = latin1_to_utf8 (ch.res_name);
+      
       XFree (ch.res_name);
     }
 
   if (ch.res_class)
     {
-      retval = latin1_to_utf8 (ch.res_class);
+      if (res_class)
+        *res_class = latin1_to_utf8 (ch.res_class);
+      
       XFree (ch.res_class);
     }
-
-  return retval;
 }
 
 void
@@ -1531,7 +1580,8 @@ get_cmap (GdkPixmap *pixmap)
       else
         {
           /* Try system cmap */
-          cmap = gdk_colormap_get_system ();
+          GdkScreen *screen = gdk_drawable_get_screen (GDK_DRAWABLE (pixmap));
+          cmap = gdk_screen_get_system_colormap (screen);
           g_object_ref (G_OBJECT (cmap));
         }
     }
@@ -1833,7 +1883,7 @@ void
 _wnck_icon_cache_set_want_fallback (WnckIconCache *icon_cache,
                                     gboolean       setting)
 {
-  icon_cache->want_fallback = TRUE;
+  icon_cache->want_fallback = setting;
 }
 
 gboolean
@@ -2290,7 +2340,7 @@ _wnck_set_desktop_layout (Screen *xscreen,
                    RootWindowOfScreen (xscreen),
 		   _wnck_atom_get ("_NET_DESKTOP_LAYOUT"),
 		   XA_CARDINAL, 32, PropModeReplace,
-		   (guchar *)&data, sizeof (data) / 4);
+		   (guchar *)&data, 4);
 
   _wnck_error_trap_pop ();
 }
